Class: IssueCentre::TicketConnection
- Inherits:
-
GenericConnection
- Object
- Savon::Client
- GenericConnection
- IssueCentre::TicketConnection
- Defined in:
- lib/issue_centre/ticket_connection.rb
Instance Method Summary collapse
-
#get_closed_tickets(session_key, company_id, page_size, page_num) ⇒ Array
Return (closed) tickets from IssueCentre for this contract.
-
#get_events_for_ticket(session_key, ticket_id) ⇒ Array
Return all events from IssueCentre for this ticket.
-
#get_open_tickets(session_key, company_id, page_size, page_num) ⇒ Array
Return (open) tickets from IssueCentre for this contract.
-
#initialize(customer_url, session_key, options = {}) ⇒ CustomerConnection
constructor
Connection client for authenticating and retrieving ticket information from IssueCentre.
Constructor Details
#initialize(customer_url, session_key, options = {}) ⇒ CustomerConnection
Connection client for authenticating and retrieving ticket information from IssueCentre
16 17 18 19 |
# File 'lib/issue_centre/ticket_connection.rb', line 16 def initialize( customer_url, session_key, = {}) # @session_key = session_key super( customer_url, ) end |
Instance Method Details
#get_closed_tickets(session_key, company_id, page_size, page_num) ⇒ Array
Return (closed) tickets from IssueCentre for this contract
61 62 63 64 65 66 67 68 69 |
# File 'lib/issue_centre/ticket_connection.rb', line 61 def get_closed_tickets( session_key, company_id, page_size, page_num) response_xml = self.call( :get_closed_tickets, message: { arg0: session_key, arg1: company_id, arg2: page_size, arg3: page_num }) response = IssueCentre::Response.parse( response_xml) end |
#get_events_for_ticket(session_key, ticket_id) ⇒ Array
Return all events from IssueCentre for this ticket
80 81 82 83 84 85 86 |
# File 'lib/issue_centre/ticket_connection.rb', line 80 def get_events_for_ticket( session_key, ticket_id) response_xml = self.call( :get_events_for_ticket, message: { arg0: session_key, arg1: ticket_id }) response = IssueCentre::Response.parse( response_xml) end |
#get_open_tickets(session_key, company_id, page_size, page_num) ⇒ Array
Return (open) tickets from IssueCentre for this contract
36 37 38 39 40 41 42 43 44 |
# File 'lib/issue_centre/ticket_connection.rb', line 36 def get_open_tickets( session_key, company_id, page_size, page_num) response_xml = self.call( :get_open_tickets, message: { arg0: session_key, arg1: company_id, arg2: page_size, arg3: page_num }) response = IssueCentre::Response.parse( response_xml) end |